@@ -124,11 +124,11 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
   if (type == "normal") {
     return(Inf)
 
-  # residual/analytical df, falls back to Inf if we have no residual df method -----
+    # residual/analytical df, falls back to Inf if we have no residual df method -----
   } else if (type == "residual") {
     dof <- .get_residual_df(x, verbose)
 
-  # Wald df - always Inf for z-statistic, 1 for Chi2-statistic, else residual df -----
+    # Wald df - always Inf for z-statistic, 1 for Chi2-statistic, else residual df -----
   } else if (type == "wald") {
     # z-statistic always Inf, *unless* we have residual df (which we have for some models)
     if (identical(statistic, "z-statistic")) {
@@ -141,15 +141,15 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
     # Wald t-statistic
     dof <- .get_residual_df(x, verbose)
 
-  # ml1 - only for certain mixed models -----
+    # ml1 - only for certain mixed models -----
   } else if (type == "ml1") {
     dof <- .degrees_of_freedom_ml1(x)
 
-  # between-within - only for certain mixed models -----
+    # between-within - only for certain mixed models -----
   } else if (type == "betwithin") {
     dof <- .degrees_of_freedom_betwithin(x)
 
-  # remaining option is model-based df, i.e. number of estimated parameters
+    # remaining option is model-based df, i.e. number of estimated parameters
   } else {
     dof <- .model_df(x)
   }
@@ -234,8 +234,10 @@ get_df.fixest <- function(x, type = "residual", ...) {
 get_df.lmerMod <- function(x, type = "residual", ...) {
   type <- match.arg(
     tolower(type),
-    choices = c("residual", "model", "analytical", "satterthwaite", "kenward",
-                "kenward-roger", "kr", "normal", "wald", "ml1", "betwithin")
+    choices = c(
+      "residual", "model", "analytical", "satterthwaite", "kenward",
+      "kenward-roger", "kr", "normal", "wald", "ml1", "betwithin"
+    )
   )
 
   dots <- list(...)
