@@ -4,7 +4,8 @@
 #' @description Collection of small helper functions. `trim_ws()` is an
 #' efficient function to trim leading and trailing whitespaces from character
 #' vectors or strings. `n_unique()` returns the number of unique values in a
-#' vector. `safe_deparse()` is comparable to `deparse1()`, i.e. it can safely
+#' vector. `has_single_value()` is equivalent to `n_unique() == 1` but is faster.
+#' `safe_deparse()` is comparable to `deparse1()`, i.e. it can safely
 #' deparse very long expressions into a single string. `safe_deparse_symbol()`
 #' only deparses a substituted expressions when possible, which can be much faster
 #' than `deparse(substitute())` for those cases where `substitute()` returns no
@@ -16,14 +17,28 @@
 #' only processes character vectors.
 #' @param ... Currently not used.
 #'
-#' @return For a vector, `n_unique` always returns an integer value, even if the
-#' input is `NULL` (the return value will be `0` then). For data frames or lists,
-#' `n_unique()` returns a named numeric vector, with the number of unique values
-#' for each element.
+#' @return
+#' - `n_unique()`: For a vector, `n_unique` always returns an integer value,
+#'   even if the input is `NULL` (the return value will be `0` then). For data
+#'   frames or lists, `n_unique()` returns a named numeric vector, with the
+#'   number of unique values for each element.
+#' - `has_single_value()`: `TRUE` if `x` has only one unique value,
+#'   `FALSE` otherwise.
+#' - `trim_ws()`: A character vector, where trailing and leading white spaces
+#'   are removed.
+#' - `safe_deparse()`: A character string of the unevaluated expression or symbol.
+#' - `safe_deparse_symbol()`: A character string of the unevaluated expression
+#'   or symbol, if `x` was a symbol. If `x` is no symbol (i.e. if `is.name(x)`
+#'   would return `FALSE`), `NULL` is returned.
 #'
 #' @examples
 #' trim_ws("  no space!  ")
 #' n_unique(iris$Species)
+#' has_single_value(c(1, 1, 2))
+#'
+#' # safe_deparse_symbol() compared to deparse(substitute())
+#' safe_deparse_symbol(as.name("test"))
+#' deparse(substitute(as.name("test")))
 #' @export
 trim_ws <- function(x, ...) {
   UseMethod("trim_ws")
@@ -77,7 +92,7 @@ n_unique.default <- function(x, na.rm = TRUE, ...) {
   if (is.null(x)) {
     return(0)
   }
-  if (isTRUE(na.rm)) x <- stats::na.omit(x)
+  if (isTRUE(na.rm)) x <- x[!is.na(x)]
   length(unique(x))
 }
 
@@ -118,3 +133,13 @@ safe_deparse_symbol <- function(x) {
   }
   return(out)
 }
+
+
+# has_single_value ---------------------------------------
+
+#' @rdname trim_ws
+#' @export
+has_single_value <- function(x, na.rm = FALSE) {
+  if (na.rm) x <- x[!is.na(x)]
+  !is.null(x) &&  isTRUE(all(x == x[1]))
+}
