@@ -19,8 +19,8 @@ if (.runThisTest) {
     test_that("get_predicted.brmsfit: ordinal dv", {
       skip_if_not_installed("bayestestR")
 
-      pred1 <- get_predicted(m8, ci = .95)
-      pred2 <- get_predicted(m8, ci_method = "hdi", ci = .95)
+      pred1 <- get_predicted(m8, ci = 0.95)
+      pred2 <- get_predicted(m8, ci_method = "hdi", ci = 0.95)
       expect_true(inherits(pred1, "get_predicted"))
       expect_true(inherits(pred1, "data.frame"))
       expect_true(all(c("Row", "Response") %in% colnames(pred1)))
@@ -36,7 +36,7 @@ if (.runThisTest) {
       expect_false(mean(pred1$CI_high == pred2$CI_high) > 0.1) # most CI bounds are different
 
       # compare to manual predictions
-      pred3 <- get_predicted(m8, centrality_function = stats::median, ci = .95)
+      pred3 <- get_predicted(m8, centrality_function = stats::median, ci = 0.95)
       manual <- rstantools::posterior_epred(m8)
       manual <- apply(manual[, , 1], 2, median)
       expect_equal(pred3$Predicted[1:32], manual)
@@ -535,18 +535,20 @@ if (.runThisTest) {
 
     test_that("Issue #645", {
       # apparently BH is required to fit these brms models
-      skip_if_not_installed("BH") 
+      skip_if_not_installed("BH")
 
-      void <- capture.output(suppressMessages(suppressWarnings(({
-      mod <- brm(
-        silent = 2,
-        data = mtcars,
-        family = cumulative(probit),
-        formula = bf(
-          cyl ~ 1 + mpg + drat + gearnl,
-          gearnl ~ 0 + (1 | gear),
-          nl = TRUE))
-      }))))
+      void <- suppressMessages(suppressWarnings(capture.output(
+        mod <- brm(
+          silent = 2,
+          data = mtcars,
+          family = cumulative(probit),
+          formula = bf(
+            cyl ~ 1 + mpg + drat + gearnl,
+            gearnl ~ 0 + (1 | gear),
+            nl = TRUE
+          )
+        )
+      )))
 
       p <- find_predictors(mod, flatten = TRUE)
       d <- get_data(mod)
@@ -863,6 +865,4 @@ if (.runThisTest) {
       )
     })
   }
-
-
 }
