@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("crch")) {
+if (requiet("testthat") &&
+  requiet("insight") &&
+  requiet("crch")) {
   data("RainIbk")
   RainIbk$sqrtensmean <- apply(sqrt(RainIbk[, grep("^rainfc", names(RainIbk))]), 1, mean)
   RainIbk$sqrtenssd <- apply(sqrt(RainIbk[, grep("^rainfc", names(RainIbk))]), 1, sd)
