@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("lfe")) {
+if (requiet("testthat") &&
+  requiet("insight") &&
+  requiet("lfe")) {
   x <- rnorm(1000)
   x2 <- rnorm(length(x))
   id <- factor(sample(20, length(x), replace = TRUE))
@@ -76,6 +76,24 @@ if (require("testthat") &&
     )
   })
 
+  test_that("get_df", {
+    expect_equal(
+      get_df(m1, type = "residual"),
+      df.residual(m1),
+      ignore_attr = TRUE
+    )
+    expect_equal(
+      get_df(m1, type = "normal"),
+      Inf,
+      ignore_attr = TRUE
+    )
+    expect_equal(
+      get_df(m1, type = "wald"),
+      964,
+      ignore_attr = TRUE
+    )
+  })
+
   test_that("find_formula", {
     expect_length(find_formula(m1), 3)
     expect_equal(
