@@ -29,7 +29,7 @@ test_that("lm", {
 test_that("get_data lavaan", {
   requiet("lavaan")
   data(PoliticalDemocracy)
-  model <- '
+  model <- "
     # latent variable definitions
       ind60 =~ x1 + x2 + x3
       dem60 =~ y1 + a*y2 + b*y3 + c*y4
@@ -45,7 +45,7 @@ test_that("get_data lavaan", {
       y3 ~~ y7
       y4 ~~ y8
       y6 ~~ y8
-  '
+  "
   m <- sem(model, data = PoliticalDemocracy)
   expect_s3_class(get_data(m), "data.frame")
   expect_equal(head(get_data(m)), head(PoliticalDemocracy), ignore_attr = TRUE, tolerance = 1e-3)
@@ -59,15 +59,15 @@ test_that("get_data include weights, even if ones", {
   wn <- runif(100)
   w1 <- rep(1, 100)
 
-  #Model with nonuniform weights
+  # Model with nonuniform weights
   fn <- lm(y ~ x, weights = wn)
   expect_equal(colnames(get_data(fn)), c("y", "x", "(weights)", "wn"))
 
-  #Model with weights equal to 1
+  # Model with weights equal to 1
   f1 <- lm(y ~ x, weights = w1)
   expect_equal(colnames(get_data(f1)), c("y", "x", "(weights)", "w1"))
 
-  #Model with no weights
+  # Model with no weights
   f0 <- lm(y ~ x)
   expect_equal(colnames(get_data(f0)), c("y", "x"))
 
