@@ -1,6 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
-if (.runThisTest && require("testthat") && require("insight") && require("metaBMA")) {
+if (.runThisTest && requiet("testthat") && requiet("insight") && requiet("metaBMA")) {
   data(towels)
   set.seed(123)
   mf <- meta_fixed(logOR, SE, study, data = towels, d = prior("norm", c(mean = 0, sd = .3), lower = 0))
@@ -13,11 +13,11 @@ if (.runThisTest && require("testthat") && require("insight") && require("metaBM
 
 
   set.seed(123)
-  mr <- meta_random(logOR, SE, study,
+  mr <- suppressWarnings(meta_random(logOR, SE, study,
     data = towels,
     d = prior("cauchy", c(location = 0, scale = 0.707)),
     tau = prior("invgamma", c(shape = 1, scale = 0.15))
-  )
+  ))
 
   test_that("get_priors-metaBMA", {
     priors <- get_priors(mr)
