@@ -31,6 +31,24 @@ if (.runThisTest && Sys.getenv("USER") != "travis") {
       )
     })
 
+    test_that("get_df", {
+      expect_equal(
+        get_df(m1, type = "residual"),
+        df.residual(m1),
+        ignore_attr = TRUE
+      )
+      expect_equal(
+        get_df(m1, type = "normal"),
+        Inf,
+        ignore_attr = TRUE
+      )
+      expect_equal(
+        get_df(m1, type = "wald"),
+        Inf,
+        ignore_attr = TRUE
+      )
+    })
+
     test_that("find_random", {
       expect_identical(find_random(m1), list(random = "village"))
     })
